==> devpulse_cli-0.1.3.tar.gz: devpulse_cli-0.1.3/devpulse/commands/focus.py <==
import typer

app = typer.Typer(help="Focus mode and distraction blocking")


@app.command()
def start(
    duration: int = typer.Option(60, "--duration", "-d", help="Focus duration in minutes"),
    goal: str = typer.Option(None, "--goal", "-g", help="Focus session goal")
):
    """Start focus mode."""
    typer.echo(f"🎯 Focus mode activated for {duration} minutes")
    if goal:
        typer.echo(f"Goal: {goal}")
    typer.echo("Distractions blocked... [Future: real blocking implementation]")


@app.command()
def stop():
    """Stop focus mode."""
    typer.echo("🎯 Focus mode stopped")
    typer.echo("Session duration: 60m 0s")
    typer.echo("Interruptions: 0")


@app.command()
def status():
    """Check focus mode status."""
    typer.echo("🎯 Focus Mode: Inactive")
    typer.echo("Last session: 60m with 0 interruptions")


@app.command()
def block(
    app_name: str = typer.Argument(..., help="App/website to block"),
    duration: int = typer.Option(60, "--duration", "-d", help="Block duration in minutes")
):
    """Block a distracting app or website."""
    typer.echo(f"🚫 Blocking {app_name} for {duration} minutes")
    typer.echo("✅ Block activated!")


@app.command()
def unblock(app_name: str = typer.Argument(..., help="App/website to unblock")):
    """Unblock an app or website."""
    typer.echo(f"✅ Unblocked {app_name}")


@app.command()
def history(limit: int = typer.Option(10, "--limit", "-l")):
    """View focus history."""
    typer.echo(f"📊 Last {limit} focus sessions:")
    typer.echo("No sessions recorded.")


@app.command()
def stats():
    """Show focus statistics."""
    typer.echo("📈 Focus Statistics:")
    typer.echo("Total focus time: 0h")
    typer.echo("Average session: 0m")
    typer.echo("Completion rate: 0%")

==> devpulse_cli-0.2.0.tar.gz: devpulse_cli-0.2.0/devpulse/commands/focus.py <==
import typer

app = typer.Typer(help="Focus mode and distraction blocking")


@app.command()
def start(
    duration: int = typer.Option(60, "--duration", "-d", help="Focus duration in minutes"),
    goal: str = typer.Option(None, "--goal", "-g", help="Focus session goal")
):
    """Start focus mode."""
    typer.echo(f"[*] Focus mode activated for {duration} minutes")
    if goal:
        typer.echo(f"Goal: {goal}")
    typer.echo("Distractions blocked... [Future: real blocking implementation]")


@app.command()
def stop():
    """Stop focus mode."""
    typer.echo("[*] Focus mode stopped")
    typer.echo("Session duration: 60m 0s")
    typer.echo("Interruptions: 0")


@app.command()
def status():
    """Check focus mode status."""
    typer.echo("[*] Focus Mode: Inactive")
    typer.echo("Last session: 60m with 0 interruptions")


@app.command()
def block(
    app_name: str = typer.Argument(..., help="App/website to block"),
    duration: int = typer.Option(60, "--duration", "-d", help="Block duration in minutes")
):
    """Block a distracting app or website."""
    typer.echo(f"🚫 Blocking {app_name} for {duration} minutes")
    typer.echo("[OK] Block activated!")


@app.command()
def unblock(app_name: str = typer.Argument(..., help="App/website to unblock")):
    """Unblock an app or website."""
    typer.echo(f"[OK] Unblocked {app_name}")


@app.command()
def history(limit: int = typer.Option(10, "--limit", "-l")):
    """View focus history."""
    typer.echo(f"📊 Last {limit} focus sessions:")
    typer.echo("No sessions recorded.")


@app.command()
def stats():
    """Show focus statistics."""
    typer.echo("📈 Focus Statistics:")
    typer.echo("Total focus time: 0h")
    typer.echo("Average session: 0m")
    typer.echo("Completion rate: 0%")
